@@ -82,10 +82,10 @@ extern "C" {
 #define ITCL_MAJOR_VERSION	4
 #define ITCL_MINOR_VERSION	3
 #define ITCL_RELEASE_LEVEL      TCL_FINAL_RELEASE
-#define ITCL_RELEASE_SERIAL     4
+#define ITCL_RELEASE_SERIAL     5
 
 #define ITCL_VERSION            "4.3"
-#define ITCL_PATCH_LEVEL        "4.3.4"
+#define ITCL_PATCH_LEVEL        "4.3.5"
 
 
 /*
@@ -183,7 +183,7 @@ typedef struct Itcl_InterpState_ *Itcl_InterpState;
  * Include all the public API, generated from itcl.decls.
  */
 
-#include "itclDecls.h"
+#include "itclDecls.h"  /* IWYU pragma: export */
 
 #endif /* RC_INVOKED */
 
