@@ -166,6 +166,59 @@ RootCallProc(
 #  define STRINGIFY1(x) #x
 #endif
 
+static const char version[] = PACKAGE_VERSION "+" STRINGIFY(ITCL_VERSION_UUID)
+#if defined(__clang__) && defined(__clang_major__)
+    ".clang-" STRINGIFY(__clang_major__)
+#if __clang_minor__ < 10
+    "0"
+#endif
+    STRINGIFY(__clang_minor__)
+#endif
+#if defined(__cplusplus) && !defined(__OBJC__)
+    ".cplusplus"
+#endif
+#ifndef NDEBUG
+    ".debug"
+#endif
+#if !defined(__clang__) && !defined(__INTEL_COMPILER) && defined(__GNUC__)
+    ".gcc-" STRINGIFY(__GNUC__)
+#if __GNUC_MINOR__ < 10
+    "0"
+#endif
+    STRINGIFY(__GNUC_MINOR__)
+#endif
+#ifdef __INTEL_COMPILER
+    ".icc-" STRINGIFY(__INTEL_COMPILER)
+#endif
+#ifdef TCL_MEM_DEBUG
+    ".memdebug"
+#endif
+#if defined(_MSC_VER)
+    ".msvc-" STRINGIFY(_MSC_VER)
+#endif
+#ifdef USE_NMAKE
+    ".nmake"
+#endif
+#ifndef TCL_CFG_OPTIMIZED
+    ".no-optimize"
+#endif
+#ifdef __OBJC__
+    ".objective-c"
+#if defined(__cplusplus)
+    "plusplus"
+#endif
+#endif
+#ifdef TCL_CFG_PROFILED
+    ".profile"
+#endif
+#ifdef PURIFY
+    ".purify"
+#endif
+#ifdef STATIC_BUILD
+    ".static"
+#endif
+;
+
 static int
 Initialize (
     Tcl_Interp *interp)
@@ -326,7 +379,7 @@ Initialize (
     if (clazzObjectPtr == NULL) {
 	Tcl_AppendResult(interp,
 		"ITCL: cannot get Object for ::itcl::clazz for class \"",
-		"::itcl::clazz", "\"", NULL);
+		"::itcl::clazz", "\"", (char *)NULL);
 	return TCL_ERROR;
     }
 
@@ -408,59 +461,14 @@ Initialize (
      */
 
     if (Tcl_GetCommandInfo(interp, "::tcl::build-info", &info)) {
+#if TCL_MAJOR_VERSION > 8
+	if (info.isNativeObjectProc == 2) {
+	    Tcl_CreateObjCommand2(interp, "::itcl::build-info",
+		    info.objProc2, (void *)version, NULL);
+	} else
+#endif
 	Tcl_CreateObjCommand(interp, "::itcl::build-info",
-		info.objProc, (void *)(PACKAGE_VERSION "+" STRINGIFY(ITCL_VERSION_UUID)
-#if defined(__clang__) && defined(__clang_major__)
-	    ".clang-" STRINGIFY(__clang_major__)
-#if __clang_minor__ < 10
-	    "0"
-#endif
-	    STRINGIFY(__clang_minor__)
-#endif
-#if defined(__cplusplus) && !defined(__OBJC__)
-	    ".cplusplus"
-#endif
-#ifndef NDEBUG
-	    ".debug"
-#endif
-#if !defined(__clang__) && !defined(__INTEL_COMPILER) && defined(__GNUC__)
-	    ".gcc-" STRINGIFY(__GNUC__)
-#if __GNUC_MINOR__ < 10
-	    "0"
-#endif
-	    STRINGIFY(__GNUC_MINOR__)
-#endif
-#ifdef __INTEL_COMPILER
-	    ".icc-" STRINGIFY(__INTEL_COMPILER)
-#endif
-#ifdef TCL_MEM_DEBUG
-	    ".memdebug"
-#endif
-#if defined(_MSC_VER)
-	    ".msvc-" STRINGIFY(_MSC_VER)
-#endif
-#ifdef USE_NMAKE
-	    ".nmake"
-#endif
-#ifndef TCL_CFG_OPTIMIZED
-	    ".no-optimize"
-#endif
-#ifdef __OBJC__
-	    ".objective-c"
-#if defined(__cplusplus)
-	    "plusplus"
-#endif
-#endif
-#ifdef TCL_CFG_PROFILED
-	    ".profile"
-#endif
-#ifdef PURIFY
-	    ".purify"
-#endif
-#ifdef STATIC_BUILD
-	    ".static"
-#endif
-		), NULL);
+		info.objProc, (void *)version, NULL);
     }
     Tcl_PkgProvideEx(interp, "Itcl", ITCL_PATCH_LEVEL, &itclStubs);
     return Tcl_PkgProvideEx(interp, "itcl", ITCL_PATCH_LEVEL, &itclStubs);
@@ -565,7 +573,7 @@ ItclCheckSetItclHull(
 
     if (objc < 3) {
 	Tcl_AppendResult(interp, "ItclCheckSetItclHull wrong # args should be ",
-		"<objectName> <value>", NULL);
+		"<objectName> <value>", (char *)NULL);
 	return TCL_ERROR;
     }
 
@@ -580,7 +588,7 @@ ItclCheckSetItclHull(
 	ioPtr = infoPtr->currIoPtr;
 	if (ioPtr == NULL) {
 	    Tcl_AppendResult(interp, "ItclCheckSetItclHull cannot find object",
-		    NULL);
+		    (char *)NULL);
 	    return TCL_ERROR;
 	}
     }
@@ -589,7 +597,7 @@ ItclCheckSetItclHull(
     Tcl_DecrRefCount(objPtr);
     if (hPtr == NULL) {
 	Tcl_AppendResult(interp, "ItclCheckSetItclHull cannot find itcl_hull",
-		" variable for object \"", Tcl_GetString(objv[1]), "\"", NULL);
+		" variable for object \"", Tcl_GetString(objv[1]), "\"", (char *)NULL);
 	return TCL_ERROR;
     }
     ivPtr = (ItclVariable *)Tcl_GetHashValue(hPtr);
@@ -601,7 +609,7 @@ ItclCheckSetItclHull(
 	    ivPtr->initted = 0;
 	} else {
 	    Tcl_AppendResult(interp, "ItclCheckSetItclHull bad value \"",
-		    valueStr, "\"", NULL);
+		    valueStr, "\"", (char *)NULL);
 	    return TCL_ERROR;
 	}
     }
