@@ -37,12 +37,12 @@
 typedef struct ItclCfunc {
     Tcl_CmdProc *argCmdProc;        /* old-style (argc,argv) command handler */
     Tcl_ObjCmdProc *objCmdProc;     /* new (objc,objv) command handler */
-    ClientData clientData;          /* client data passed into this function */
+    void *clientData;               /* client data passed into this function */
     Tcl_CmdDeleteProc *deleteProc;  /* proc called to free clientData */
 } ItclCfunc;
 
 static Tcl_HashTable* ItclGetRegisteredProcs(Tcl_Interp *interp);
-static void ItclFreeC(ClientData clientData, Tcl_Interp *interp);
+static void ItclFreeC(void *clientData, Tcl_Interp *interp);
 
 
 /*
@@ -78,7 +78,7 @@ Itcl_RegisterC(
     Tcl_Interp *interp,             /* interpreter handling this registration */
     const char *name,               /* symbolic name for procedure */
     Tcl_CmdProc *proc,              /* procedure handling Tcl command */
-    ClientData clientData,          /* client data associated with proc */
+    void *clientData,               /* client data associated with proc */
     Tcl_CmdDeleteProc *deleteProc)  /* proc called to free up client data */
 {
     int newEntry;
@@ -90,10 +90,10 @@ Itcl_RegisterC(
      *  Make sure that a proc was specified.
      */
     if (!proc) {
-        Tcl_AppendResult(interp, "initialization error: null pointer for ",
-            "C procedure \"", name, "\"",
-            NULL);
-        return TCL_ERROR;
+	Tcl_AppendResult(interp, "initialization error: null pointer for ",
+	    "C procedure \"", name, "\"",
+	    (char *)NULL);
+	return TCL_ERROR;
     }
 
     /*
@@ -104,20 +104,20 @@ Itcl_RegisterC(
     procTable = ItclGetRegisteredProcs(interp);
     entry = Tcl_CreateHashEntry(procTable, name, &newEntry);
     if (!newEntry) {
-        cfunc = (ItclCfunc*)Tcl_GetHashValue(entry);
-        if (cfunc->argCmdProc != NULL && cfunc->argCmdProc != proc) {
-            Tcl_AppendResult(interp, "initialization error: C procedure ",
-                "with name \"", name, "\" already defined",
-                NULL);
-            return TCL_ERROR;
-        }
+	cfunc = (ItclCfunc*)Tcl_GetHashValue(entry);
+	if (cfunc->argCmdProc != NULL && cfunc->argCmdProc != proc) {
+	    Tcl_AppendResult(interp, "initialization error: C procedure ",
+		"with name \"", name, "\" already defined",
+		(char *)NULL);
+	    return TCL_ERROR;
+	}
 
-        if (cfunc->deleteProc != NULL) {
-            (*cfunc->deleteProc)(cfunc->clientData);
-        }
+	if (cfunc->deleteProc != NULL) {
+	    (*cfunc->deleteProc)(cfunc->clientData);
+	}
     } else {
-        cfunc = (ItclCfunc*)ckalloc(sizeof(ItclCfunc));
-        cfunc->objCmdProc = NULL;
+	cfunc = (ItclCfunc*)ckalloc(sizeof(ItclCfunc));
+	cfunc->objCmdProc = NULL;
     }
 
     cfunc->argCmdProc = proc;
@@ -162,7 +162,7 @@ Itcl_RegisterObjC(
     Tcl_Interp *interp,     /* interpreter handling this registration */
     const char *name,       /* symbolic name for procedure */
     Tcl_ObjCmdProc *proc,   /* procedure handling Tcl command */
-    ClientData clientData,          /* client data associated with proc */
+    void *clientData,       /* client data associated with proc */
     Tcl_CmdDeleteProc *deleteProc)  /* proc called to free up client data */
 {
     int newEntry;
@@ -174,10 +174,10 @@ Itcl_RegisterObjC(
      *  Make sure that a proc was specified.
      */
     if (!proc) {
-        Tcl_AppendResult(interp, "initialization error: null pointer for ",
-            "C procedure \"", name, "\"",
-            NULL);
-        return TCL_ERROR;
+	Tcl_AppendResult(interp, "initialization error: null pointer for ",
+	    "C procedure \"", name, "\"",
+	    (char *)NULL);
+	return TCL_ERROR;
     }
 
     /*
@@ -188,21 +188,20 @@ Itcl_RegisterObjC(
     procTable = ItclGetRegisteredProcs(interp);
     entry = Tcl_CreateHashEntry(procTable, name, &newEntry);
     if (!newEntry) {
-        cfunc = (ItclCfunc*)Tcl_GetHashValue(entry);
-        if (cfunc->objCmdProc != NULL && cfunc->objCmdProc != proc) {
-            Tcl_AppendResult(interp, "initialization error: C procedure ",
-                "with name \"", name, "\" already defined",
-                NULL);
-            return TCL_ERROR;
-        }
+	cfunc = (ItclCfunc*)Tcl_GetHashValue(entry);
+	if (cfunc->objCmdProc != NULL && cfunc->objCmdProc != proc) {
+	    Tcl_AppendResult(interp, "initialization error: C procedure ",
+		"with name \"", name, "\" already defined",
+		(char *)NULL);
+	    return TCL_ERROR;
+	}
 
-        if (cfunc->deleteProc != NULL) {
-            (*cfunc->deleteProc)(cfunc->clientData);
-        }
-    }
-    else {
-        cfunc = (ItclCfunc*)ckalloc(sizeof(ItclCfunc));
-        cfunc->argCmdProc = NULL;
+	if (cfunc->deleteProc != NULL) {
+	    (*cfunc->deleteProc)(cfunc->clientData);
+	}
+    } else {
+	cfunc = (ItclCfunc*)ckalloc(sizeof(ItclCfunc));
+	cfunc->argCmdProc = NULL;
     }
 
     cfunc->objCmdProc = proc;
@@ -213,6 +212,50 @@ Itcl_RegisterObjC(
     return TCL_OK;
 }
 
+#if TCL_MAJOR_VERSION > 8
+
+typedef struct {
+    Tcl_ObjCmdProc2 *objProc;
+    void *clientData;
+    Tcl_CmdDeleteProc *deleteProc;
+} regInfo;
+
+static int regCmdProc(
+    void *clientData,
+    Tcl_Interp *interp,
+    int argc,
+    Tcl_Obj *const *objv)
+{
+    regInfo *info = (regInfo *)clientData;
+    return info->objProc(info->clientData, interp, argc, objv);
+}
+
+static void reg2DeleteProc(
+    void *clientData)
+{
+    regInfo *info = (regInfo *)clientData;
+    if (info->deleteProc != NULL) {
+	info->deleteProc(info->clientData);
+    }
+    ckfree(info);
+}
+
+
+int
+Itcl_RegisterObjC2(
+    Tcl_Interp *interp,     /* interpreter handling this registration */
+    const char *name,       /* symbolic name for procedure */
+    Tcl_ObjCmdProc2 *proc,   /* procedure handling Tcl command */
+    void *clientData,       /* client data associated with proc */
+    Tcl_CmdDeleteProc *deleteProc)  /* proc called to free up client data */
+{
+    regInfo *info = (regInfo *)ckalloc(sizeof(regInfo));
+    info->objProc = proc;
+    info->clientData = clientData;
+    info->deleteProc = deleteProc;
+    return Itcl_RegisterObjC(interp, name, regCmdProc, info, reg2DeleteProc);
+}
+#endif /* TCL_MAJOR_VERSION */
 
 /*
  * ------------------------------------------------------------------------
@@ -230,35 +273,63 @@ int
 Itcl_FindC(
     Tcl_Interp *interp,           /* interpreter handling this registration */
     const char *name,             /* symbolic name for procedure */
-    Tcl_CmdProc **argProcPtr,     /* returns (argc,argv) command handler */
+    Tcl_CmdProc **argProcPtr,     /* returns (argc,argv) command handler, can be NULL */
     Tcl_ObjCmdProc **objProcPtr,  /* returns (objc,objv) command handler */
-    ClientData *cDataPtr)         /* returns client data */
+    void **cDataPtr)              /* returns client data */
 {
     Tcl_HashEntry *entry;
     Tcl_HashTable *procTable;
     ItclCfunc *cfunc;
+    Tcl_CmdProc *argProc = NULL;  /* assume info won't be found */
 
-    *argProcPtr = NULL;  /* assume info won't be found */
     *objProcPtr = NULL;
     *cDataPtr   = NULL;
 
     if (interp) {
-        procTable = (Tcl_HashTable*)Tcl_GetAssocData(interp,
-            "itcl_RegC", NULL);
+	procTable = (Tcl_HashTable*)Tcl_GetAssocData(interp,
+	    "itcl_RegC", NULL);
 
-        if (procTable) {
-            entry = Tcl_FindHashEntry(procTable, name);
-            if (entry) {
-                cfunc = (ItclCfunc*)Tcl_GetHashValue(entry);
-                *argProcPtr = cfunc->argCmdProc;
-                *objProcPtr = cfunc->objCmdProc;
-                *cDataPtr   = cfunc->clientData;
-            }
-        }
+	if (procTable) {
+	    entry = Tcl_FindHashEntry(procTable, name);
+	    if (entry) {
+		cfunc = (ItclCfunc*)Tcl_GetHashValue(entry);
+		argProc = cfunc->argCmdProc;
+		*objProcPtr = cfunc->objCmdProc;
+		*cDataPtr   = cfunc->clientData;
+	    }
+	}
     }
-    return (*argProcPtr != NULL || *objProcPtr != NULL);
+    if (argProcPtr) {
+	*argProcPtr = argProc;
+    }
+    return (((argProcPtr != NULL) && (argProc != NULL)) || (*objProcPtr != NULL));
 }
 
+#if TCL_MAJOR_VERSION > 8
+int
+Itcl_FindC2(
+    Tcl_Interp *interp,           /* interpreter handling this registration */
+    const char *name,             /* symbolic name for procedure */
+    Tcl_ObjCmdProc2 **objProcPtr, /* returns (objc,objv) command handler */
+    void **cDataPtr)              /* returns client data */
+{
+    Tcl_ObjCmdProc *regProcPtr;
+    void *dataPtr;
+
+    *objProcPtr = NULL;  /* assume info won't be found */
+    *cDataPtr = NULL;
+
+    if (Itcl_FindC(interp, name, NULL, &regProcPtr, &dataPtr)) {
+	if (regProcPtr == regCmdProc) {
+	    regInfo *info = (regInfo *)dataPtr;
+	    *objProcPtr = info->objProc;
+	    *cDataPtr = info->clientData;
+	}
+    }
+    return (*objProcPtr != NULL);
+}
+#endif /* TCL_MAJOR_VERSION */
+
 
 /*
  * ------------------------------------------------------------------------
@@ -279,13 +350,13 @@ ItclGetRegisteredProcs(
      *  If the registration table does not yet exist, then create it.
      */
     procTable = (Tcl_HashTable*)Tcl_GetAssocData(interp, "itcl_RegC",
-        NULL);
+	NULL);
 
     if (!procTable) {
-        procTable = (Tcl_HashTable*)ckalloc(sizeof(Tcl_HashTable));
-        Tcl_InitHashTable(procTable, TCL_STRING_KEYS);
-        Tcl_SetAssocData(interp, "itcl_RegC", ItclFreeC,
-            procTable);
+	procTable = (Tcl_HashTable*)ckalloc(sizeof(Tcl_HashTable));
+	Tcl_InitHashTable(procTable, TCL_STRING_KEYS);
+	Tcl_SetAssocData(interp, "itcl_RegC", ItclFreeC,
+	    procTable);
     }
     return procTable;
 }
@@ -302,7 +373,7 @@ ItclGetRegisteredProcs(
  */
 static void
 ItclFreeC(
-    ClientData clientData,       /* associated data */
+    void *clientData,            /* associated data */
     TCL_UNUSED(Tcl_Interp *))    /* interpreter being deleted */
 {
     Tcl_HashTable *tablePtr = (Tcl_HashTable*)clientData;
@@ -312,13 +383,13 @@ ItclFreeC(
 
     entry = Tcl_FirstHashEntry(tablePtr, &place);
     while (entry) {
-        cfunc = (ItclCfunc*)Tcl_GetHashValue(entry);
+	cfunc = (ItclCfunc*)Tcl_GetHashValue(entry);
 
-        if (cfunc->deleteProc != NULL) {
-            (*cfunc->deleteProc)(cfunc->clientData);
-        }
-        ckfree ( (char*)cfunc );
-        entry = Tcl_NextHashEntry(&place);
+	if (cfunc->deleteProc != NULL) {
+	    (*cfunc->deleteProc)(cfunc->clientData);
+	}
+	ckfree ( (char*)cfunc );
+	entry = Tcl_NextHashEntry(&place);
     }
 
     Tcl_DeleteHashTable(tablePtr);
