@@ -10,7 +10,7 @@
  *  AUTHOR:  Arnulf Wiedemann
  *
  * ========================================================================
- *           Copyright (c) 1993-1998  Lucent Technologies, Inc.
+ *	   Copyright (c) 1993-1998  Lucent Technologies, Inc.
  * ------------------------------------------------------------------------
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
@@ -42,7 +42,7 @@ _Tcl_SetNamespaceResolver(
     Tcl_Resolve *resolvePtr)
 {
     if (nsPtr == NULL) {
-        return TCL_ERROR;
+	return TCL_ERROR;
     }
 #ifdef ITCL_USE_MODIFIED_TCL_H
     ((Namespace *)nsPtr)->resolvePtr = resolvePtr;
@@ -62,12 +62,14 @@ Tcl_NewNamespaceVar(
     int isNew;
 
     if ((nsPtr == NULL) || (varName == NULL)) {
-        return NULL;
+	return NULL;
     }
 
     varPtr = TclVarHashCreateVar(&((Namespace *)nsPtr)->varTable,
-            varName, &isNew);
-    TclSetVarNamespaceVar(varPtr);
+	    varName, &isNew);
+    if (varPtr) {
+	TclSetVarNamespaceVar(varPtr);
+    }
     return (Tcl_Var)varPtr;
 }
 
@@ -97,14 +99,14 @@ Itcl_GetUplevelCallFrame(
 {
     CallFrame *framePtr;
     if (level < 0) {
-        return NULL;
+	return NULL;
     }
     framePtr = ((Interp *)interp)->varFramePtr;
     while ((framePtr != NULL) && (level-- > 0)) {
-        framePtr = framePtr->callerVarPtr;
+	framePtr = framePtr->callerVarPtr;
     }
     if (framePtr == NULL) {
-        return NULL;
+	return NULL;
     }
     return (Tcl_CallFrame *)framePtr;
 }
@@ -130,19 +132,19 @@ Itcl_GetUplevelNamespace(
 {
     CallFrame *framePtr;
     if (level < 0) {
-        return NULL;
+	return NULL;
     }
     framePtr = ((Interp *)interp)->framePtr;
     while ((framePtr != NULL) && (level-- > 0)) {
-        framePtr = framePtr->callerVarPtr;
+	framePtr = framePtr->callerVarPtr;
     }
     if (framePtr == NULL) {
-        return NULL;
+	return NULL;
     }
     return (Tcl_Namespace *)framePtr->nsPtr;
 }
 
-ClientData
+void *
 Itcl_GetCallFrameClientData(
     Tcl_Interp *interp)
 {
@@ -151,7 +153,7 @@ Itcl_GetCallFrameClientData(
      */
     CallFrame *framePtr = ((Interp *)interp)->varFramePtr;
     if (framePtr == NULL) {
-        return NULL;
+	return NULL;
     }
     return framePtr->clientData;
 }
@@ -163,52 +165,52 @@ Itcl_SetCallFrameNamespace(
 {
     CallFrame *framePtr = ((Interp *)interp)->varFramePtr;
     if (framePtr == NULL) {
-        return TCL_ERROR;
+	return TCL_ERROR;
     }
     ((Interp *)interp)->varFramePtr->nsPtr = (Namespace *)nsPtr;
     return TCL_OK;
 }
 
-int
+size_t
 Itcl_GetCallVarFrameObjc(
     Tcl_Interp *interp)
 {
     CallFrame *framePtr = ((Interp *)interp)->varFramePtr;
     if (framePtr == NULL) {
-        return 0;
+	return 0;
     }
     return framePtr->objc;
 }
 
-Tcl_Obj * const *
+Tcl_Obj *const *
 Itcl_GetCallVarFrameObjv(
     Tcl_Interp *interp)
 {
     CallFrame *framePtr = ((Interp *)interp)->varFramePtr;
     if (framePtr == NULL) {
-        return NULL;
+	return NULL;
     }
     return framePtr->objv;
 }
 
-int
+Tcl_Size
 Itcl_GetCallFrameObjc(
     Tcl_Interp *interp)
 {
     CallFrame *framePtr = ((Interp *)interp)->framePtr;
     if (framePtr == NULL) {
-        return 0;
+	return 0;
     }
     return ((Interp *)interp)->framePtr->objc;
 }
 
-Tcl_Obj * const *
+Tcl_Obj *const *
 Itcl_GetCallFrameObjv(
     Tcl_Interp *interp)
 {
     CallFrame *framePtr = ((Interp *)interp)->framePtr;
     if (framePtr == NULL) {
-        return NULL;
+	return NULL;
     }
     return ((Interp *)interp)->framePtr->objv;
 }
@@ -222,29 +224,29 @@ Itcl_IsCallFrameArgument(
     Proc *procPtr;
 
     if (varFramePtr == NULL) {
-        return 0;
+	return 0;
     }
     if (!varFramePtr->isProcCallFrame) {
-        return 0;
+	return 0;
     }
     procPtr = varFramePtr->procPtr;
     /*
      *  Search through compiled locals first...
      */
     if (procPtr) {
-        CompiledLocal *localPtr = procPtr->firstLocalPtr;
-        int nameLen = strlen(name);
+	CompiledLocal *localPtr = procPtr->firstLocalPtr;
+	int nameLen = strlen(name);
 
-        for (;localPtr != NULL; localPtr = localPtr->nextPtr) {
-            if (TclIsVarArgument(localPtr)) {
-                char *localName = localPtr->name;
-                if ((name[0] == localName[0])
-                        && (nameLen == localPtr->nameLength)
-                        && (strcmp(name, localName) == 0)) {
-                    return 1;
-                }
-            }
-        }
+	for (;localPtr != NULL; localPtr = localPtr->nextPtr) {
+	    if (TclIsVarArgument(localPtr)) {
+		char *localName = localPtr->name;
+		if ((name[0] == localName[0])
+			&& (nameLen == localPtr->nameLength)
+			&& (strcmp(name, localName) == 0)) {
+		    return 1;
+		}
+	    }
+	}
     }
     return 0;
 }
